@@ -215,11 +215,10 @@ pub(crate) fn _start_set_64(buf: &mut [u8], c: u8) {
         {
             let unroll = 8;
             let loop_size = 8;
-            let end_ptr_8_8 = unsafe { end_ptr.sub(loop_size * unroll) };
-            while a_ptr <= end_ptr_8_8 {
+            while unsafe { end_ptr.offset_from(a_ptr) } >= (loop_size * unroll) as isize {
                 for i in 0..unroll {
                     let aa_ptr = unsafe { a_ptr.add(loop_size * i) } as *mut u64;
-                    unsafe { *aa_ptr = cc };
+                    unsafe { aa_ptr.write_unaligned(cc) };
                 }
                 a_ptr = unsafe { a_ptr.add(loop_size * unroll) };
             }
@@ -227,21 +226,19 @@ pub(crate) fn _start_set_64(buf: &mut [u8], c: u8) {
         {
             let unroll = 4;
             let loop_size = 8;
-            let end_ptr_8_4 = unsafe { end_ptr.sub(loop_size * unroll) };
-            while a_ptr <= end_ptr_8_4 {
+            while unsafe { end_ptr.offset_from(a_ptr) } >= (loop_size * unroll) as isize {
                 for i in 0..unroll {
                     let aa_ptr = unsafe { a_ptr.add(loop_size * i) } as *mut u64;
-                    unsafe { *aa_ptr = cc };
+                    unsafe { aa_ptr.write_unaligned(cc) };
                 }
                 a_ptr = unsafe { a_ptr.add(loop_size * unroll) };
             }
         }
         {
             let loop_size = 8;
-            let end_ptr_8 = unsafe { end_ptr.sub(loop_size) };
-            while a_ptr <= end_ptr_8 {
+            while unsafe { end_ptr.offset_from(a_ptr) } >= loop_size as isize {
                 let aa_ptr = a_ptr as *mut u64;
-                unsafe { *aa_ptr = cc };
+                unsafe { aa_ptr.write_unaligned(cc) };
                 a_ptr = unsafe { a_ptr.add(loop_size) };
             }
         }
@@ -259,10 +256,9 @@ fn _start_set_64_no_unroll(buf: &mut [u8], c: u8) {
     let cc: u64 = c as u64 * 0x0101_0101_0101_0101_u64;
     if buf_len > 7 {
         let loop_size = 8;
-        let end_ptr_8 = unsafe { end_ptr.sub(loop_size) };
-        while a_ptr <= end_ptr_8 {
+        while unsafe { end_ptr.offset_from(a_ptr) } >= loop_size as isize {
             let aa_ptr = a_ptr as *mut u64;
-            unsafe { *aa_ptr = cc };
+            unsafe { aa_ptr.write_unaligned(cc) };
             a_ptr = unsafe { a_ptr.add(loop_size) };
         }
     }
@@ -287,11 +283,10 @@ fn _start_set_32(buf: &mut [u8], c: u8) {
         {
             let unroll = 8;
             let loop_size = 4;
-            let end_ptr_4_8 = unsafe { end_ptr.sub(loop_size * unroll) };
-            while a_ptr <= end_ptr_4_8 {
+            while unsafe { end_ptr.offset_from(a_ptr) } >= (loop_size * unroll) as isize {
                 for i in 0..unroll {
                     let aa_ptr = unsafe { a_ptr.add(loop_size * i) } as *mut u32;
-                    unsafe { *aa_ptr = cc };
+                    unsafe { aa_ptr.write_unaligned(cc) };
                 }
                 a_ptr = unsafe { a_ptr.add(loop_size * unroll) };
             }
@@ -299,21 +294,19 @@ fn _start_set_32(buf: &mut [u8], c: u8) {
         {
             let unroll = 4;
             let loop_size = 4;
-            let end_ptr_4_4 = unsafe { end_ptr.sub(loop_size * unroll) };
-            while a_ptr <= end_ptr_4_4 {
+            while unsafe { end_ptr.offset_from(a_ptr) } >= (loop_size * unroll) as isize {
                 for i in 0..unroll {
                     let aa_ptr = unsafe { a_ptr.add(loop_size * i) } as *mut u32;
-                    unsafe { *aa_ptr = cc };
+                    unsafe { aa_ptr.write_unaligned(cc) };
                 }
                 a_ptr = unsafe { a_ptr.add(loop_size * unroll) };
             }
         }
         {
             let loop_size = 4;
-            let end_ptr_4 = unsafe { end_ptr.sub(loop_size) };
-            while a_ptr <= end_ptr_4 {
+            while unsafe { end_ptr.offset_from(a_ptr) } >= loop_size as isize {
                 let aa_ptr = a_ptr as *mut u32;
-                unsafe { *aa_ptr = cc };
+                unsafe { aa_ptr.write_unaligned(cc) };
                 a_ptr = unsafe { a_ptr.add(loop_size) };
             }
         }
@@ -333,10 +326,9 @@ fn _start_set_32_no_unroll(buf: &mut [u8], c: u8) {
     a_ptr = _align_4(a_ptr, cc as u64);
     if buf_len > 3 {
         let loop_size = 4;
-        let end_ptr_4 = unsafe { end_ptr.sub(loop_size) };
-        while a_ptr <= end_ptr_4 {
+        while unsafe { end_ptr.offset_from(a_ptr) } >= loop_size as isize {
             let aa_ptr = a_ptr as *mut u32;
-            unsafe { *aa_ptr = cc };
+            unsafe { aa_ptr.write_unaligned(cc) };
             a_ptr = unsafe { a_ptr.add(loop_size) };
         }
     }
@@ -349,11 +341,10 @@ pub(crate) fn _memset_remaining_15_bytes_impl(buf_ptr: *const u8, cc: u64, end_p
     let mut a_ptr = buf_ptr;
     {
         let loop_size = 8;
-        let end_ptr_4 = unsafe { end_ptr.sub(loop_size) };
-        if a_ptr <= end_ptr_4 {
+        if unsafe { end_ptr.offset_from(a_ptr) } >= loop_size as isize {
             let cc: u64 = cc as u64;
             let aa_ptr = a_ptr as *mut u64;
-            unsafe { *aa_ptr = cc };
+            unsafe { aa_ptr.write_unaligned(cc) };
             //
             a_ptr = unsafe { a_ptr.add(loop_size) };
         }
@@ -367,11 +358,10 @@ pub(crate) fn _memset_remaining_7_bytes_impl(buf_ptr: *const u8, cc: u64, end_pt
     let mut a_ptr = buf_ptr;
     {
         let loop_size = 4;
-        let end_ptr_4 = unsafe { end_ptr.sub(loop_size) };
-        if a_ptr <= end_ptr_4 {
+        if unsafe { end_ptr.offset_from(a_ptr) } >= loop_size as isize {
             let cc: u32 = cc as u32;
             let aa_ptr = a_ptr as *mut u32;
-            unsafe { *aa_ptr = cc };
+            unsafe { aa_ptr.write_unaligned(cc) };
             //
             a_ptr = unsafe { a_ptr.add(loop_size) };
         }
@@ -385,19 +375,17 @@ pub(crate) fn _memset_remaining_3_bytes_impl(buf_ptr: *const u8, cc: u32, end_pt
     let mut a_ptr = buf_ptr;
     {
         let loop_size = 2;
-        let end_ptr_2 = unsafe { end_ptr.sub(loop_size) };
-        if a_ptr <= end_ptr_2 {
+        if unsafe { end_ptr.offset_from(a_ptr) } >= loop_size as isize {
             let cc: u16 = cc as u16;
             let aa_ptr = a_ptr as *mut u16;
-            unsafe { *aa_ptr = cc };
+            unsafe { aa_ptr.write_unaligned(cc) };
             //
             a_ptr = unsafe { a_ptr.add(loop_size) };
         }
     }
     {
         let loop_size = 1;
-        let end_ptr_1 = unsafe { end_ptr.sub(loop_size) };
-        if a_ptr <= end_ptr_1 {
+        if unsafe { end_ptr.offset_from(a_ptr) } >= loop_size as isize {
             let c: u8 = cc as u8;
             let aa_ptr = a_ptr as *mut u8;
             unsafe { *aa_ptr = c };
