@@ -1,6 +1,6 @@
 mod test_std_memcpy {
     fn test_memcpy(dst: &mut [u8], src: &[u8]) {
-        &(dst[0..src.len()]).copy_from_slice(src);
+        let _ = &(dst[0..src.len()]).copy_from_slice(src);
     }
     //
     #[test]
