@@ -4,6 +4,19 @@ mod test_memx_memmem {
     }
     //
     #[test]
+    fn test00() {
+        let buf_0 = vec![];
+        let pat_1 = vec![];
+        let pat_2 = vec![b'A', b'B', b'C', b'D', b'E', b'F', b'G', b'H', b'J', b'0'];
+        //
+        let r = test_memmem(&buf_0, &pat_1);
+        assert_eq!(r, Some(0));
+        let r = test_memmem(&buf_0, &pat_2);
+        assert_eq!(r, None);
+        let r = test_memmem(&pat_2, &pat_1);
+        assert_eq!(r, Some(0));
+    }
+    #[test]
     fn test01() {
         let buf = vec![b'A', b'B', b'C', b'D', b'E', b'F', b'G', b'H', b'J', b'K'];
         let pat = vec![b'G', b'H', b'J'];
